# dailies

![Continuous Integration (CI) Tests](https://github.com/unkokaeru/dailies/actions/workflows/continuous_integration.yml/badge.svg)

A collection of daily games inspired by NYT Games.

## Installation

To install dailies, simply run:

```bash
pip install dailies
```

## Usage

After installation, you can use the package by executing:

```bash
dailies
```

## Features

- **Connections**: To be implemented.
- **KenKen**: To be implemented.
- **Mini Crossword**: To be implemented.
- **Strands**: To be implemented.
- **Sudoku**: To be implemented.
- **Wordle**: To be implemented.

## Documentation
For more information, you can find the documentation within the `docs` directory or on the project's [GitHub Pages](https://unkokaeru.github.io/dailies/).

## Contributing

Contributions are welcome! Please refer to our `CONTRIBUTING.md` for more information.

## License

This project is licensed under the MIT License - see the `LICENSE.md` file for details.